Module value

Module value 

Definition of a MILF value

Re-exports

pub use crate::map::Map;

Structs

Datetime
A parsed MILF datetime value
DatetimeParseError
Error returned from parsing a Datetime in the FromStr implementation.

Enums

Value
Representation of a MILF value.

Traits

Index
Types that can be used to index a milf::Value

Type Aliases

Array
Type representing a MILF array, payload of the Value::Array variant
Table
Type representing a MILF table, payload of the Value::Table variant. By default it is backed by a BTreeMap, enable the preserve_order feature to use a LinkedHashMap instead.